from __future__ import annotations

import pytest

from procrastinate import exceptions, worker
from procrastinate.app import App


@pytest.fixture
async def test_worker(app: App) -> worker.Worker:
    return worker.Worker(app=app, queues=["yay"])


async def test_worker_find_task_missing(test_worker):
    with pytest.raises(exceptions.TaskNotFound):
        test_worker.find_task("foobarbaz")


async def test_worker_find_task(app: App):
    test_worker = worker.Worker(app=app, queues=["yay"])

    @app.task(name="foo")
    def task_func():
        pass

    assert test_worker.find_task("foo") == task_func


async def test_stop(test_worker, caplog):
    caplog.set_level("INFO")

    test_worker.stop()

    assert caplog.messages == ["Stop requested"]
